pub type ByteArray<Size> = GenericArray<u8, Size>;Expand description
Array of bytes representing a scalar serialized as a big endian integer.
Aliased Type
pub struct ByteArray<Size> { /* private fields */ }main (development) branch of crypto-glue.pub type ByteArray<Size> = GenericArray<u8, Size>;Array of bytes representing a scalar serialized as a big endian integer.
pub struct ByteArray<Size> { /* private fields */ }